@@ -246,13 +246,13 @@ verify_file(xmlSecKeysMngrPtr mngr, const char* xml_file) {
     /* limit the Reference URI attributes to empty or NULL */
     dsigCtx->enabledReferenceUris = xmlSecTransformUriTypeEmpty;
     
-    /* limit allowed transforms for siganture and reference processing */
+    /* limit allowed transforms for signature and reference processing */
     if((xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformExclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformSha1Id) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformRsaSha1Id) < 0)) {
 
-        fprintf(stderr,"Error: failed to limit allowed siganture transforms\n");
+        fprintf(stderr,"Error: failed to limit allowed signature transforms\n");
         goto done;
     }
     if((xmlSecDSigCtxEnableReferenceTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
