@@ -951,6 +951,7 @@ xmlSecOpenSSLX509VerifyCertAgainstCrls(STACK_OF(X509_CRL) *crls, X509* cert) {
      * Try to retrieve a CRL corresponding to the issuer of
      * the current certificate
      */
+    issuer = X509_get_issuer_name(cert);
     n = sk_X509_CRL_num(crls);
     for(i = 0; i < n; i++) {
         crl = sk_X509_CRL_value(crls, i);
@@ -958,7 +959,6 @@ xmlSecOpenSSLX509VerifyCertAgainstCrls(STACK_OF(X509_CRL) *crls, X509* cert) {
             continue;
         }
 
-        issuer = X509_CRL_get_issuer(crl);
         if(xmlSecOpenSSLX509NamesCompare(X509_CRL_get_issuer(crl), issuer) == 0) {
             break;
         }
